@@ -199,20 +199,7 @@ where
 
         emit!(self, n.name);
         formatting_space!(self);
-        punct!(self, "{");
-        formatting_newline!(self);
-
-        self.emit_list(
-            &n.blocks,
-            if self.config.minify {
-                ListFormat::NotDelimited
-            } else {
-                ListFormat::MultiLine
-            },
-        )?;
-
-        formatting_newline!(self);
-        punct!(self, "}");
+        emit!(self, n.block);
     }
 
     #[emitter]
@@ -888,7 +875,7 @@ where
                 ComponentValue::StyleBlock(_) if idx == 0 => {
                     formatting_newline!(self);
                 }
-                ComponentValue::Rule(_) => {
+                ComponentValue::Rule(_) | ComponentValue::KeyframeBlock(_) => {
                     formatting_newline!(self);
                 }
                 ComponentValue::DeclarationBlockItem(_) if idx == 0 => {
@@ -918,6 +905,11 @@ where
                     }
                     StyleBlock::Invalid(_) => {}
                 },
+                ComponentValue::KeyframeBlock(_) => {
+                    if idx == len - 1 {
+                        formatting_newline!(self);
+                    }
+                }
                 ComponentValue::DeclarationBlockItem(i) => match i {
                     DeclarationBlockItem::AtRule(_) => {
                         formatting_newline!(self);
@@ -951,6 +943,7 @@ where
             ComponentValue::DeclarationBlockItem(n) => emit!(self, n),
             ComponentValue::Rule(n) => emit!(self, n),
             ComponentValue::Value(n) => emit!(self, n),
+            ComponentValue::KeyframeBlock(n) => emit!(self, n),
         }
     }
 
